package com.ls11.dominohelper;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import lotus.domino.Session;

/**
 * Helper class to detect whether the current thread is running within an XPages application
 * 
 * @author Karsten Lehmann
 */
public class XPagesDetector {

	/**
	 * Method to check whether we are in an XPages application
	 * 
	 * @return true, if XPages app
	 */
	public static boolean isXPagesContext() {
		try {
			Class<?> ctxClazz=Class.forName("com.ibm.domino.xsp.module.nsf.NotesContext");
			Method m=ctxClazz.getMethod("getCurrentUnchecked", (Class[]) null);
			Object ctxInstance=m.invoke((Object) null, (Object[]) null);
			if (ctxInstance!=null) {
				if (getXspContextSession()!=null)
					return true;
			}
			return false;
		} catch (ClassNotFoundException e) {
			return false;
		} catch (SecurityException e) {
			return false;
		} catch (NoSuchMethodException e) {
			return false;
		} catch (IllegalArgumentException e) {
			return false;
		} catch (IllegalAccessException e) {
			return false;
		} catch (InvocationTargetException e) {
			return false;
		}
	}

	/**
	 * Returns the Session of the current XPages request
	 * 
	 * @return session, null in case of errors
	 */
	public static Session getXspContextSession() {
		try {
			Class<?> ctxClazz = Class.forName("com.ibm.domino.xsp.module.nsf.NotesContext");
			Method m=ctxClazz.getMethod("getCurrent", (Class[]) null);
			Object ctxInstance=m.invoke((Object) null, (Object[]) null);
			Method m2=ctxInstance.getClass().getMethod("getCurrentSession", (Class[]) null);
			Session session=(Session) m2.invoke(ctxInstance, (Object[]) null);
			return session;
		} catch (ClassNotFoundException e) {
			return null;
		} catch (SecurityException e) {
			return null;
		} catch (NoSuchMethodException e) {
			return null;
		} catch (IllegalArgumentException e) {
			return null;
		} catch (IllegalAccessException e) {
			return null;
		} catch (InvocationTargetException e) {
			return null;
		}
	}
	
}
